aboutsummaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
Diffstat (limited to 'gcc')
-rw-r--r--gcc/f/ChangeLog5
-rw-r--r--gcc/f/g77.texi6
-rw-r--r--gcc/f/g77spec.c8
-rw-r--r--gcc/f/invoke.texi4
-rw-r--r--gcc/f/lang-specs.h4
5 files changed, 16 insertions, 11 deletions
diff --git a/gcc/f/ChangeLog b/gcc/f/ChangeLog
index 25d34a7..40804ef 100644
--- a/gcc/f/ChangeLog
+++ b/gcc/f/ChangeLog
@@ -1,3 +1,8 @@
+2003-03-12 Nathanael Nerode <neroden@gcc.gnu.org>
+
+ * g77.texi, invoke.texi, g77spec.c, lang-specs.h: GCC, not
+ GNU CC. Especially here.
+
2003-03-10 Roger Sayle <roger@eyesopen.com>
* com.c (duplicate_decls): Synchronize with C's duplicate_decls.
diff --git a/gcc/f/g77.texi b/gcc/f/g77.texi
index 3c1fce2..b37b20e 100644
--- a/gcc/f/g77.texi
+++ b/gcc/f/g77.texi
@@ -250,7 +250,7 @@ many people have helped create and improve GNU Fortran.
@itemize @bullet
@item
The packaging and compiler portions of GNU Fortran are based largely
-on the GNU CC compiler.
+on the GCC compiler.
@xref{Contributors,,Contributors to GCC,gcc,Using the GNU Compiler
Collection (GCC)},
for more information.
@@ -800,7 +800,7 @@ but apply to other languages as well.
@xref{G++ and GCC,,Compile C; C++; Objective-C; Ada; Fortran;
or Java,gcc,Using the GNU Compiler Collection (GCC)},
for information on the way different languages are handled
-by the GNU CC compiler (@command{gcc}).
+by the GCC compiler (@command{gcc}).
@cindex @command{g77}, command
@cindex commands, @command{g77}
@@ -10987,7 +10987,7 @@ ways to find it:
@item
Look in the service directory for someone who might help you for a fee.
The service directory is found in the file named @file{SERVICE} in the
-GNU CC distribution.
+GCC distribution.
@item
Send a message to @email{@value{email-help}}.
diff --git a/gcc/f/g77spec.c b/gcc/f/g77spec.c
index 3df5062..2153a37 100644
--- a/gcc/f/g77spec.c
+++ b/gcc/f/g77spec.c
@@ -1,20 +1,20 @@
/* Specific flags and argument handling of the Fortran front-end.
Copyright (C) 1997, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
-This file is part of GNU CC.
+This file is part of GCC.
-GNU CC is free software; you can redistribute it and/or modify
+GCC is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
-GNU CC is distributed in the hope that it will be useful,
+GCC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING. If not, write to
+along with GCC; see the file COPYING. If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA. */
diff --git a/gcc/f/invoke.texi b/gcc/f/invoke.texi
index 50c7ca4..3079d70 100644
--- a/gcc/f/invoke.texi
+++ b/gcc/f/invoke.texi
@@ -255,7 +255,7 @@ program is written is generally indicated by the suffix.
Suffixes specific to GNU Fortran are listed below.
@xref{Overall Options,,Options Controlling the Kind of
Output,gcc,Using the GNU Compiler Collection (GCC)}, for
-information on suffixes recognized by GNU CC.
+information on suffixes recognized by GCC.
@table @gcctabopt
@cindex .f filename suffix
@@ -286,7 +286,7 @@ You can force @samp{.f} files to be preprocessed by @command{cpp} by using
@item @var{file}.fpp
@item @var{file}.FPP
Fortran source code that must be preprocessed (by the C preprocessor
-@command{cpp}, which is part of GNU CC).
+@command{cpp}, which is part of GCC).
Note that preprocessing is not extended to the contents of
files included by the @code{INCLUDE} directive---the @code{#include}
diff --git a/gcc/f/lang-specs.h b/gcc/f/lang-specs.h
index 46a4528..3c8c8e1 100644
--- a/gcc/f/lang-specs.h
+++ b/gcc/f/lang-specs.h
@@ -35,8 +35,8 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
f771 %|.f %(cc1_options) %{I*} %{!fsyntax-only:%(invoke_as)}}}}", 0},
{".r", "@ratfor", 0},
{"@ratfor",
- "%{C:%{!E:%eGNU C does not support -C without using -E}}\
- %{CC:%{!E:%eGNU C does not support -CC without using -E}}\
+ "%{C:%{!E:%eGCC does not support -C without using -E}}\
+ %{CC:%{!E:%eGCC does not support -CC without using -E}}\
ratfor %{C} %{CC} %{v} %{E:%W{o*}} %{!E: %{!pipe:-o %g.f} %i |\n\
f771 %m.f %(cc1_options) %{I*} %{!fsyntax-only:%(invoke_as)}}", 0},
{".f", "@f77", 0},